# `okdata-cli`: Oslo Origo Dataplatform CLI

Okdata CLI provides a unified interface to the services provided by Oslo Origo Dataplatform.

```bash
$ okdata

usage:
  okdata datasets [options]
  okdata status [options]
  okdata pipelines [options]
  okdata events [options]
  okdata webhooks [options]
  okdata -h | --help
```

## Resources
* [Documentation at Read the Docs](https://okdata-cli.readthedocs.io/)
* [GitHub pages for Origo Dataplatform](https://oslokommune.github.io/dataplattform/)
